#[non_exhaustive]pub struct ListDataCatalogsOutput {
pub data_catalogs_summary: Option<Vec<DataCatalogSummary>>,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data_catalogs_summary: Option<Vec<DataCatalogSummary>>A summary list of data catalogs.
next_token: Option<String>A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Implementations
Sourceimpl ListDataCatalogsOutput
impl ListDataCatalogsOutput
Sourcepub fn data_catalogs_summary(&self) -> &[DataCatalogSummary]
pub fn data_catalogs_summary(&self) -> &[DataCatalogSummary]
A summary list of data catalogs.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .data_catalogs_summary.is_none().
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourceimpl ListDataCatalogsOutput
impl ListDataCatalogsOutput
Sourcepub fn builder() -> ListDataCatalogsOutputBuilder
pub fn builder() -> ListDataCatalogsOutputBuilder
Creates a new builder-style object to manufacture ListDataCatalogsOutput.